@@ -1,5 +1,5 @@
 /* error.c --- Error handling functionality.
- * Copyright (C) 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009, 2010  Simon Josefsson
+ * Copyright (C) 2002-2012 Simon Josefsson
  *
  * This file is part of GNU SASL Library.
  *
@@ -36,7 +36,9 @@
 #define OBS(i, name, desc) { name, #name, desc }
 #endif
 
-static struct {
+/* *INDENT-OFF* */
+static struct
+{
   int rc;
   const char *name;
   const char *description;
@@ -195,9 +197,17 @@ static struct {
   ERR (GSASL_GSSAPI_TEST_OID_SET_MEMBER_ERROR,
        N_("GSSAPI error testing for OID in OID set.")),
   ERR (GSASL_GSSAPI_RELEASE_OID_SET_ERROR,
-       N_("GSSAPI error releasing OID set."))
-
+       N_("GSSAPI error releasing OID set.")),
+  ERR (GSASL_NO_CB_TLS_UNIQUE,
+       N_("Authentication failed because a tls-unique CB was not provided.")),
+  ERR (GSASL_NO_SAML20_IDP_IDENTIFIER,
+       N_("Callback failed to provide SAML20 user identifier.")),
+  ERR (GSASL_NO_SAML20_REDIRECT_URL,
+       N_("Callback failed to provide SAML20 redirect URL.")),
+  ERR (GSASL_NO_OPENID20_AUTH_IDENTIFIER,
+       N_("Callback failed to provide OPENID20 authentication identifier."))
 };
+/* *INDENT-ON* */
 
 /**
  * gsasl_strerror:
@@ -247,7 +257,7 @@ gsasl_strerror (int err)
  * a successful call to gsasl_init().
  *
  * Return value: Returns a pointer to a statically allocated string
- *   containing a string version of the error code @err, or %NULL if
+ *   containing a string version of the error code @err, or NULL if
  *   the error code is not known.
  *
  * Since: 0.2.29
